pytest_mock: Thin-wrapper around the mock package for easier use with pytest
============================================================================

Description
-----------

Thin-wrapper around the mock package for easier use with pytest

License
-------

MIT

Upstream Contact
----------------

https://pypi.org/project/pytest-mock/

